---
template: mainpage
source_form: markdown
name: Credits
updated: July 2015
title: Credits
---
## Credits

This page aims to detail who is directly responsible for what, and where appropriate
indirectly.

### Directly

{% michael = panel("panels/credits-michael-sparks.md") %}
{% contrib1 = panel("panels/credits-contributor.md") %}

### Projects used by Pyxie (etc)

Listing key projects used here is a way of saying thank you :-)

{% contrib2 = panel("panels/credits-ply.md") %}
